"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AiNativeBrowserContribution = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const command_1 = require("@opensumi/ide-core-browser/lib/ai-native/command");
const components_1 = require("@opensumi/ide-core-browser/lib/components");
const ai_native_1 = require("@opensumi/ide-core-browser/lib/contextkey/ai-native");
const layout_state_1 = require("@opensumi/ide-core-browser/lib/layout/layout-state");
const next_1 = require("@opensumi/ide-core-browser/lib/menu/next");
const ai_native_2 = require("@opensumi/ide-core-common/lib/types/ai-native");
const browser_1 = require("@opensumi/ide-editor/lib/browser");
const ide_preferences_1 = require("@opensumi/ide-preferences");
const ide_terminal_next_1 = require("@opensumi/ide-terminal-next");
const common_1 = require("../common");
const ai_chat_service_1 = require("./ai-chat.service");
const ai_chat_view_1 = require("./ai-chat.view");
const ai_editor_contribution_1 = require("./ai-editor.contribution");
const generate_service_1 = require("./ai-project/generate.service");
const sumi_service_1 = require("./ai-sumi/sumi.service");
const ai_diff_document_provider_1 = require("./diff-widget/ai-diff-document.provider");
const completeProvider_1 = require("./inline-completions/completeProvider");
const ai_completions_service_1 = require("./inline-completions/service/ai-completions.service");
const menu_bar_service_1 = require("./override/layout/menu-bar/menu-bar.service");
const tabbar_view_1 = require("./override/layout/tabbar.view");
const run_service_1 = require("./run/run.service");
const run_toolbar_1 = require("./run/toolbar/run-toolbar");
const types_1 = require("./types");
let AiNativeBrowserContribution = class AiNativeBrowserContribution {
    constructor() {
        this.registerFeature();
    }
    onStart() {
        this.aiProject.initRequirements();
    }
    onDidStart() {
        this.aiSumi.classifyCommand();
    }
    registerFeature() {
        this.contributions.getContributions().forEach((contribution) => {
            if (contribution.registerRunFeature) {
                contribution.registerRunFeature(this.aiRunFeatureRegistry);
            }
            if (contribution.registerInlineChatFeature) {
                contribution.registerInlineChatFeature(this.inlineChatFeatureRegistry);
            }
            if (contribution.registerRenameProvider) {
                contribution.registerRenameProvider(this.renameCandidatesProviderRegistry);
            }
        });
    }
    handleSettingGroup(settingGroup) {
        return [
            ...settingGroup,
            {
                id: common_1.AI_NATIVE_SETTING_GROUP_ID,
                title: common_1.AI_NATIVE_SETTING_GROUP_ID,
                iconClass: (0, ide_core_browser_1.getIcon)('magic-wand'),
            },
        ];
    }
    handleSettingSections(settingSections) {
        const groups = [];
        if (this.aiNativeConfigService.capabilities.supportsInlineChat) {
            groups.push({
                title: 'Inline Chat',
                preferences: [
                    {
                        id: common_1.AiNativeSettingSectionsId.INLINE_CHAT_AUTO_VISIBLE,
                        localized: 'preference.aiNative.inlineChat.auto.visible',
                    },
                ],
            });
        }
        return Object.assign(Object.assign({}, settingSections), { [common_1.AI_NATIVE_SETTING_GROUP_ID]: groups });
    }
    registerComponent(registry) {
        registry.register(common_1.Ai_CHAT_CONTAINER_VIEW_ID, {
            component: ai_chat_view_1.AiChatView,
            id: common_1.Ai_CHAT_CONTAINER_VIEW_ID,
        }, {
            containerId: common_1.Ai_CHAT_CONTAINER_VIEW_ID,
        });
        registry.register('AI_MENU_BAR_DEBUG_TOOLBAR', {
            id: 'AI_MENU_BAR_DEBUG_TOOLBAR',
            component: run_toolbar_1.AIRunToolbar,
        });
    }
    registerEditorFeature(registry) {
        registry.registerEditorFeatureContribution({
            contribute: (editor) => {
                const aiEditorContribution = this.injector.get(ai_editor_contribution_1.AiEditorContribution, [editor]);
                return aiEditorContribution.contribute(editor);
            },
        });
    }
    registerCommands(commands) {
        commands.registerCommand(command_1.AI_EXPLAIN_TERMINAL_COMMANDS, {
            execute: () => {
                const current = this.view.currentWidgetId;
                const client = this.terminalController.findClientFromWidgetId(current);
                if (client) {
                    const name = client.name;
                    const selectionContent = client.getSelection();
                    this.aiChatService.launchChatMessage({
                        message: `${common_1.InstructionEnum.aiExplainKey} @terminalSelection`,
                        prompt: `请解释一下这一段 ${name} 终端面板里的这部分内容: \`\`\`\n${selectionContent}\n\`\`\` `,
                    });
                }
            },
        });
        commands.registerCommand(command_1.AI_EXPLAIN_DEBUG_COMMANDS, {
            execute: (node) => {
                const description = node.description;
                if (description) {
                    this.aiChatService.launchChatMessage({
                        message: `分析以下内容：\`\`\`\n${description}\`\`\``,
                        prompt: `在 IDE 中进行调试时，程序输出了一些错误信息，请尝试解释报错并给出解决方案，报错信息如下：\`\`\`\n${description}\n\`\`\` `,
                    });
                }
            },
        });
        commands.registerCommand(command_1.AI_RUN_DEBUG_COMMANDS, {
            execute: () => {
                this.aiRunService.run();
            },
        });
        commands.registerCommand(command_1.AI_INLINE_CHAT_VISIBLE, {
            execute: (value) => {
                this.aiChatService.launchInlineChatVisible(value);
            },
        });
        commands.registerCommand(command_1.AI_INLINE_COMPLETION_REPORTET, {
            execute: (relationId, sessionId, accept) => {
                // 补全埋点统计
                this.aiCompletionsService.report({ sessionId, accept, relationId });
            },
        });
        commands.registerCommand(command_1.AI_INLINE_COMPLETION_VISIBLE, {
            execute: async (visible) => {
                if (!visible) {
                    await this.commandService.executeCommand('editor.action.inlineSuggest.hide');
                    this.aiCompletionsService.hideStatusBarItem();
                    this.aiInlineCompletionsProvider.resetContextKey();
                    this.aiInlineCompletionsProvider.cancelRequest();
                    this.aiCompletionsService.setVisibleCompletion(false);
                }
            },
        });
        commands.registerCommand(command_1.AI_CHAT_PANEL_TOGGLE_VISIBLE, {
            execute: (visible) => {
                var _a;
                const { layout } = (0, components_1.getStorageValue)();
                if ((_a = layout[common_1.Ai_CHAT_CONTAINER_VIEW_ID]) === null || _a === void 0 ? void 0 : _a.currentId) {
                    this.updateLayoutState({
                        currentId: '',
                        // 默认初始化尺寸有问题，在这里修正
                        size: common_1.AI_CHAT_DEFAULT_SIZE,
                    });
                }
                else {
                    this.updateLayoutState({
                        currentId: common_1.Ai_CHAT_CONTAINER_VIEW_ID,
                        // 默认初始化尺寸有问题，在这里修正
                        size: common_1.AI_CHAT_DEFAULT_SIZE,
                    });
                }
                if (visible === true) {
                    this.aiMenubarService.showRightPanel();
                    return;
                }
                if (visible === false) {
                    if (this.aiMenubarService.getLatestWidth() === 0) {
                        this.aiMenubarService.toggleRightPanel();
                    }
                    return;
                }
                this.aiMenubarService.toggleRightPanel();
            },
        });
        // 拦截 git.stage 命令，来统计智能解决冲突的数据
        commands.beforeExecuteCommand('git.stage', (args) => args);
    }
    // TerminalClient
    registerMenus(menus) {
        menus.registerMenuItem(next_1.MenuId.TerminalInstanceContext, {
            command: command_1.AI_EXPLAIN_TERMINAL_COMMANDS,
            group: '0_ai',
        });
        menus.registerMenuItem(next_1.MenuId.DebugConsoleContext, {
            command: command_1.AI_EXPLAIN_DEBUG_COMMANDS,
            group: '0_ai',
        });
    }
    registerEditorDocumentModelContentProvider(registry) {
        registry.registerEditorDocumentModelContentProvider(this.aiDiffDocumentProvider);
    }
    registerResource(resourceService) {
        resourceService.registerResourceProvider({
            scheme: 'AI',
            provideResource: async (uri) => ({
                uri,
                icon: (0, ide_core_browser_1.getIcon)('file-text'),
                name: `AI Diff ${uri.displayName}`,
            }),
        });
    }
    registerRenderer(registry) {
        if (this.aiNativeConfigService.capabilities.supportsOpenSumiDesign) {
            registry.registerSlotRenderer(ide_core_browser_1.SlotLocation.left, tabbar_view_1.AiLeftTabRenderer);
            registry.registerSlotRenderer(ide_core_browser_1.SlotLocation.right, tabbar_view_1.AiRightTabRenderer);
            registry.registerSlotRenderer(ide_core_browser_1.SlotLocation.bottom, tabbar_view_1.AiBottomTabRenderer);
            registry.registerSlotRenderer(common_1.Ai_CHAT_CONTAINER_VIEW_ID, tabbar_view_1.AiChatTabRenderer);
        }
    }
    registerKeybindings(keybindings) {
        if (this.aiNativeConfigService.capabilities.supportsInlineChat) {
            keybindings.registerKeybinding({
                command: command_1.AI_INLINE_CHAT_VISIBLE.id,
                keybinding: 'ctrlcmd+i',
                when: 'editorTextFocus',
                args: true,
                priority: 0,
            }, ide_core_browser_1.KeybindingScope.USER);
            keybindings.registerKeybinding({
                command: command_1.AI_INLINE_CHAT_VISIBLE.id,
                keybinding: 'esc',
                args: false,
                when: `editorFocus && ${ai_native_1.InlineChatIsVisible.raw}`,
            });
        }
        if (this.aiNativeConfigService.capabilities.supportsInlineCompletion) {
            keybindings.registerKeybinding({
                command: command_1.AI_INLINE_COMPLETION_VISIBLE.id,
                keybinding: 'esc',
                args: false,
                when: `editorFocus && ${ai_native_1.InlineCompletionIsTrigger.raw}`,
            });
        }
    }
    updateLayoutState(stateVal) {
        this.layoutState.setState(layout_state_1.LAYOUT_STATE.MAIN, Object.assign(Object.assign({}, this.layoutState.getState(layout_state_1.LAYOUT_STATE.MAIN, {})), { [common_1.Ai_CHAT_CONTAINER_VIEW_ID]: stateVal }));
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(),
    tslib_1.__metadata("design:type", ai_diff_document_provider_1.AiDiffDocumentProvider)
], AiNativeBrowserContribution.prototype, "aiDiffDocumentProvider", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(di_1.INJECTOR_TOKEN),
    tslib_1.__metadata("design:type", di_1.Injector)
], AiNativeBrowserContribution.prototype, "injector", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ai_chat_service_1.AiChatService),
    tslib_1.__metadata("design:type", ai_chat_service_1.AiChatService)
], AiNativeBrowserContribution.prototype, "aiChatService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_terminal_next_1.ITerminalGroupViewService),
    tslib_1.__metadata("design:type", Object)
], AiNativeBrowserContribution.prototype, "view", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_terminal_next_1.ITerminalController),
    tslib_1.__metadata("design:type", Object)
], AiNativeBrowserContribution.prototype, "terminalController", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(run_service_1.AiRunService),
    tslib_1.__metadata("design:type", run_service_1.AiRunService)
], AiNativeBrowserContribution.prototype, "aiRunService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(generate_service_1.AiProjectGenerateService),
    tslib_1.__metadata("design:type", generate_service_1.AiProjectGenerateService)
], AiNativeBrowserContribution.prototype, "aiProject", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(sumi_service_1.AiSumiService),
    tslib_1.__metadata("design:type", sumi_service_1.AiSumiService)
], AiNativeBrowserContribution.prototype, "aiSumi", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(types_1.AiNativeCoreContribution),
    tslib_1.__metadata("design:type", Object)
], AiNativeBrowserContribution.prototype, "contributions", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(types_1.IAiRunFeatureRegistry),
    tslib_1.__metadata("design:type", Object)
], AiNativeBrowserContribution.prototype, "aiRunFeatureRegistry", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(types_1.IInlineChatFeatureRegistry),
    tslib_1.__metadata("design:type", Object)
], AiNativeBrowserContribution.prototype, "inlineChatFeatureRegistry", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.CommandService),
    tslib_1.__metadata("design:type", Object)
], AiNativeBrowserContribution.prototype, "commandService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(completeProvider_1.AiInlineCompletionsProvider),
    tslib_1.__metadata("design:type", completeProvider_1.AiInlineCompletionsProvider)
], AiNativeBrowserContribution.prototype, "aiInlineCompletionsProvider", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ai_completions_service_1.AiCompletionsService),
    tslib_1.__metadata("design:type", ai_completions_service_1.AiCompletionsService)
], AiNativeBrowserContribution.prototype, "aiCompletionsService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.AiNativeConfigService),
    tslib_1.__metadata("design:type", ide_core_browser_1.AiNativeConfigService)
], AiNativeBrowserContribution.prototype, "aiNativeConfigService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(menu_bar_service_1.AiMenubarService),
    tslib_1.__metadata("design:type", menu_bar_service_1.AiMenubarService)
], AiNativeBrowserContribution.prototype, "aiMenubarService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(layout_state_1.LayoutState),
    tslib_1.__metadata("design:type", layout_state_1.LayoutState)
], AiNativeBrowserContribution.prototype, "layoutState", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ai_native_2.RenameCandidatesProviderRegistryToken),
    tslib_1.__metadata("design:type", Object)
], AiNativeBrowserContribution.prototype, "renameCandidatesProviderRegistry", void 0);
AiNativeBrowserContribution = tslib_1.__decorate([
    (0, di_1.Injectable)(),
    (0, ide_core_browser_1.Domain)(ide_core_browser_1.ClientAppContribution, ide_core_browser_1.ComponentContribution, browser_1.BrowserEditorContribution, next_1.MenuContribution, ide_core_browser_1.CommandContribution, ide_core_browser_1.SlotRendererContribution, ide_preferences_1.SettingContribution, ide_core_browser_1.KeybindingContribution),
    tslib_1.__metadata("design:paramtypes", [])
], AiNativeBrowserContribution);
exports.AiNativeBrowserContribution = AiNativeBrowserContribution;
//# sourceMappingURL=ai-core.contribution.js.map