"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThinkingResult = exports.Thinking = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const components_1 = require("@opensumi/ide-core-browser/lib/components");
const ai_native_1 = require("@opensumi/ide-core-browser/lib/components/ai-native");
const progress_bar_1 = require("@opensumi/ide-core-browser/lib/progress/progress-bar");
const reporter_1 = require("@opensumi/ide-core-common/lib/ai-native/reporter");
const common_1 = require("../../common");
const ai_chat_service_1 = require("../ai-chat.service");
const msg_stream_manager_1 = require("../model/msg-stream-manager");
const styles = tslib_1.__importStar(require("./components.module.less"));
const Thinking = ({ children, status, message, onStop, showStop = true, hasAgent, thinkingText, }) => {
    const aiChatService = (0, ide_core_browser_1.useInjectable)(ai_chat_service_1.AiChatService);
    const msgStreamManager = (0, ide_core_browser_1.useInjectable)(msg_stream_manager_1.MsgStreamManager);
    const handlePause = (0, react_1.useCallback)(async () => {
        // agent 处理有另外的流程
        if (!hasAgent) {
            aiChatService.cancelChatViewToken();
            const { currentSessionId } = msgStreamManager;
            if (currentSessionId) {
                await aiChatService.destroyStreamRequest(currentSessionId);
            }
        }
        onStop && onStop();
    }, [msgStreamManager]);
    const renderContent = (0, react_1.useCallback)(() => {
        if (!children || (status === 1 /* EMsgStreamStatus.THINKING */ && !(message === null || message === void 0 ? void 0 : message.trim()))) {
            return react_1.default.createElement("span", { className: styles.thinking_text }, thinkingText || 'Thinking...');
        }
        return children;
    }, [status, message, children]);
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("div", { className: styles.content }, renderContent()),
        react_1.default.createElement("div", { className: styles.thinking_container },
            react_1.default.createElement("div", { className: styles.stop },
                react_1.default.createElement("span", { className: styles.progress_bar }, (!!status || !children) && (react_1.default.createElement(progress_bar_1.Progress, { loading: true, wrapperClassName: styles.ai_native_progress_wrapper }))),
                showStop && (react_1.default.createElement("div", { className: styles.block, onClick: handlePause },
                    react_1.default.createElement(components_1.Icon, { className: (0, components_1.getIcon)('circle-pause') }),
                    react_1.default.createElement("span", null, "\u505C\u6B62")))))));
};
exports.Thinking = Thinking;
const ThinkingResult = ({ children, message, status, onRegenerate, sessionId, hasMessage, regenerateDisabled, }) => {
    const aiChatService = (0, ide_core_browser_1.useInjectable)(ai_chat_service_1.AiChatService);
    const aiReporter = (0, ide_core_browser_1.useInjectable)(reporter_1.IAIReporter);
    const [latestSessionId, setLatestSessionId] = (0, react_1.useState)(undefined);
    (0, react_1.useEffect)(() => {
        const dispose = aiChatService.onChangeSessionId((sid) => {
            setLatestSessionId(sid);
        });
        return () => dispose.dispose();
    }, [aiChatService]);
    const handleRegenerate = (0, react_1.useCallback)(() => {
        if (onRegenerate) {
            onRegenerate();
        }
    }, [onRegenerate]);
    const renderContent = (0, react_1.useCallback)(() => {
        if ((status === 2 /* EMsgStreamStatus.DONE */ || status === 0 /* EMsgStreamStatus.READY */) && typeof hasMessage === 'boolean'
            ? !hasMessage
            : !(message === null || message === void 0 ? void 0 : message.trim())) {
            return react_1.default.createElement("span", null, common_1.AiResponseTips.STOP_IMMEDIATELY);
        }
        return children;
    }, [status, message, children]);
    const isRenderRegenerate = (0, react_1.useMemo)(() => aiChatService.latestSessionId === sessionId, [sessionId, latestSessionId]);
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("div", { className: styles.content }, renderContent()),
        react_1.default.createElement("div", { className: styles.thinking_container },
            react_1.default.createElement("div", { className: styles.bottom_container },
                react_1.default.createElement("div", { className: styles.reset }, isRenderRegenerate && !regenerateDisabled ? (react_1.default.createElement(ai_native_1.EnhanceIcon, { icon: 'refresh', wrapperClassName: styles.text_btn, className: styles.transform, onClick: handleRegenerate },
                    react_1.default.createElement("span", null, "\u91CD\u65B0\u751F\u6210"))) : null),
                react_1.default.createElement("div", { className: styles.thumbs },
                    react_1.default.createElement(ai_native_1.Thumbs, { relationId: sessionId, wrapperClassName: styles.icon_btn, aiReporterService: aiReporter }))))));
};
exports.ThinkingResult = ThinkingResult;
//# sourceMappingURL=Thinking.js.map