"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AiNativeModule = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const constants_1 = require("@opensumi/ide-core-browser/lib/layout/constants");
const browser_1 = require("@opensumi/ide-core-browser/lib/menu/next/renderer/ctxmenu/browser");
const ai_native_1 = require("@opensumi/ide-core-common/lib/ai-native");
const ai_native_2 = require("@opensumi/ide-core-common/lib/types/ai-native");
const browser_2 = require("@opensumi/ide-editor/lib/browser");
const ide_markers_1 = require("@opensumi/ide-markers");
const ide_theme_1 = require("@opensumi/ide-theme");
const theme_store_1 = require("@opensumi/ide-theme/lib/browser/theme-store");
const common_1 = require("../common");
const ai_chat_service_1 = require("./ai-chat.service");
const ai_core_contribution_1 = require("./ai-core.contribution");
const chat_feature_registry_1 = require("./chat/chat.feature.registry");
const chat_agent_service_1 = require("./chat-agent.service");
const chat_agent_view_service_1 = require("./chat-agent.view.service");
const chat_manager_service_1 = require("./chat-manager.service");
const inline_chat_feature_registry_1 = require("./inline-chat-widget/inline-chat.feature.registry");
const inline_chat_service_1 = require("./inline-chat-widget/inline-chat.service");
const parser_1 = require("./languages/parser");
const merge_conflict_1 = require("./merge-conflict");
const ai_editor_tab_service_1 = require("./override/ai-editor-tab.service");
const ai_marker_service_1 = require("./override/ai-marker.service");
const ai_menu_service_1 = require("./override/ai-menu.service");
const layout_config_1 = require("./override/layout/layout-config");
const menu_bar_contribution_1 = require("./override/layout/menu-bar/menu-bar.contribution");
const default_theme_1 = tslib_1.__importDefault(require("./override/theme/default-theme"));
const light_theme_1 = tslib_1.__importDefault(require("./override/theme/light-theme"));
const rename_feature_registry_1 = require("./rename/rename.feature.registry");
const run_feature_registry_1 = require("./run/run.feature.registry");
const types_1 = require("./types");
let AiNativeModule = class AiNativeModule extends ide_core_browser_1.BrowserModule {
    constructor() {
        super(...arguments);
        this.contributionProvider = types_1.AiNativeCoreContribution;
        this.providers = [
            ai_core_contribution_1.AiNativeBrowserContribution,
            {
                token: types_1.IAiRunFeatureRegistry,
                useClass: run_feature_registry_1.AiRunFeatureRegistry,
            },
            {
                token: types_1.IInlineChatFeatureRegistry,
                useClass: inline_chat_feature_registry_1.InlineChatFeatureRegistry,
            },
            {
                token: types_1.ChatFeatureRegistryToken,
                useClass: chat_feature_registry_1.ChatFeatureRegistry,
            },
            {
                token: common_1.IAiChatService,
                useClass: ai_chat_service_1.AiChatService,
            },
            {
                token: ide_core_browser_1.IAiInlineChatService,
                useClass: inline_chat_service_1.AiInlineChatService,
            },
            {
                token: common_1.IChatManagerService,
                useClass: chat_manager_service_1.ChatManagerService,
            },
            {
                token: common_1.IChatAgentService,
                useClass: chat_agent_service_1.ChatAgentService,
            },
            {
                token: types_1.IChatAgentViewService,
                useClass: chat_agent_view_service_1.ChatAgentViewService,
            },
            {
                token: parser_1.LanguageParserFactory,
                useFactory: parser_1.LanguageParserFactory,
            },
            {
                token: ai_native_2.RenameCandidatesProviderRegistryToken,
                useClass: rename_feature_registry_1.RenameCandidatesProviderRegistry,
            },
        ];
        this.preferences = (injector) => {
            const aiNativeConfig = injector.get(ide_core_browser_1.AiNativeConfigService);
            const { layoutViewSize } = this.app.config;
            let layoutConfig = this.app.config.layoutConfig;
            // 默认开启所有配置
            aiNativeConfig.enable();
            const { capabilities } = aiNativeConfig;
            const { supportsOpenSumiDesign, supportsAiMarkers, supportsAiChatAssistant, supportsConflictResolve } = capabilities;
            if (supportsOpenSumiDesign) {
                injector.addProviders(menu_bar_contribution_1.AiMenuBarContribution);
                if (!layoutViewSize) {
                    this.app.config.layoutViewSize = Object.assign(Object.assign({}, constants_1.LAYOUT_VIEW_SIZE), { MENUBAR_HEIGHT: 48, EDITOR_TABS_HEIGHT: 36, STATUSBAR_HEIGHT: 36, ACCORDION_HEADER_SIZE_HEIGHT: 36 });
                }
                injector.overrideProviders({
                    token: browser_1.IBrowserCtxMenu,
                    useClass: ai_menu_service_1.AiBrowserCtxMenuService,
                }, {
                    // AI Native 模式下默认使用该主题
                    token: ide_theme_1.IThemeStore,
                    useClass: class extends theme_store_1.ThemeStore {
                        async getThemeData(contribution, basePath) {
                            var _a;
                            const newTheme = await super.getThemeData(contribution, basePath);
                            const theme = this.injector.get(ide_theme_1.IThemeData);
                            let themeToken;
                            if ((_a = contribution === null || contribution === void 0 ? void 0 : contribution.id) === null || _a === void 0 ? void 0 : _a.includes('light')) {
                                themeToken = light_theme_1.default;
                                document.body.classList.remove(default_theme_1.default.aiThemeType);
                            }
                            else {
                                themeToken = default_theme_1.default;
                                document.body.classList.remove(light_theme_1.default.aiThemeType);
                            }
                            document.body.classList.add(themeToken.aiThemeType);
                            theme.initializeFromData(themeToken);
                            const colors = theme.colors;
                            if (colors) {
                                for (const colorId in colors) {
                                    if (Object.prototype.hasOwnProperty.call(colors, colorId)) {
                                        const colorHex = colors[colorId];
                                        if (typeof colorHex === 'string') {
                                            newTheme.colorMap[colorId] = ide_theme_1.Color.fromHex(colors[colorId]);
                                        }
                                    }
                                }
                            }
                            const defaultRemoveColor = new ide_theme_1.Color(new ide_theme_1.RGBA(217, 108, 108, 0.2));
                            (0, ide_theme_1.registerColor)('diffEditor.removedLineBackground', { dark: defaultRemoveColor, light: defaultRemoveColor, hcDark: null, hcLight: null }, '', true);
                            const defaultInsertColor = new ide_theme_1.Color(new ide_theme_1.RGBA(108, 217, 126, 0.2));
                            (0, ide_theme_1.registerColor)('diffEditor.insertedLineBackground', { dark: defaultInsertColor, light: defaultInsertColor, hcDark: null, hcLight: null }, '', true);
                            return newTheme;
                        }
                    },
                    override: true,
                    isDefault: true,
                }, {
                    token: browser_2.IEditorTabService,
                    useClass: ai_editor_tab_service_1.AiEditorTabService,
                    override: true,
                    isDefault: true,
                });
            }
            if (supportsAiMarkers) {
                injector.overrideProviders({
                    token: ide_markers_1.IMarkerService,
                    useClass: ai_marker_service_1.AiMarkerService,
                    override: true,
                    isDefault: true,
                });
            }
            if (supportsAiChatAssistant) {
                layoutConfig = Object.assign(Object.assign({}, layoutConfig), layout_config_1.AiChatLayoutConfig);
            }
            if (supportsConflictResolve) {
                injector.addProviders(merge_conflict_1.MergeConflictContribution);
            }
            this.app.config.layoutConfig = layoutConfig;
        };
        this.backServices = [
            {
                servicePath: ai_native_1.AiBackSerivcePath,
                token: ai_native_1.AiBackSerivceToken,
                clientToken: common_1.IAiChatService,
            },
        ];
    }
};
AiNativeModule = tslib_1.__decorate([
    (0, di_1.Injectable)()
], AiNativeModule);
exports.AiNativeModule = AiNativeModule;
//# sourceMappingURL=index.js.map