"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AiInlineChatController = void 0;
const tslib_1 = require("tslib");
const debounce_1 = tslib_1.__importDefault(require("lodash/debounce"));
const react_1 = tslib_1.__importStar(require("react"));
const ide_components_1 = require("@opensumi/ide-components");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const ai_native_1 = require("@opensumi/ide-core-browser/lib/components/ai-native");
const base_1 = require("@opensumi/ide-core-browser/lib/menu/next/base");
const common_1 = require("../../common");
const Loading_1 = require("../components/Loading");
const types_1 = require("../types");
const styles = tslib_1.__importStar(require("./inline-chat.module.less"));
/**
 * 原始操作项
 */
const AiInlineOperation = (props) => {
    const { hanldeActions, onClose } = props;
    const inlineChatFeatureRegistry = (0, ide_core_browser_1.useInjectable)(types_1.IInlineChatFeatureRegistry);
    const operationList = (0, react_1.useMemo)(() => inlineChatFeatureRegistry.getActionButtons(), [inlineChatFeatureRegistry]);
    const handleClickActions = (0, react_1.useCallback)((id) => {
        hanldeActions(id);
    }, [hanldeActions]);
    const handleClose = (0, react_1.useCallback)(() => {
        if (onClose) {
            onClose();
        }
    }, [onClose]);
    const moreOperation = (0, react_1.useMemo)(() => inlineChatFeatureRegistry.getActionMenus().map((data) => new base_1.MenuNode({
        id: `ai.menu.operation.${data.id}`,
        label: data.name,
        className: styles.more_operation_menu_item,
        execute: () => {
            handleClickActions(data.id);
        },
    })), [inlineChatFeatureRegistry]);
    if (operationList.length === 0 && moreOperation.length === 0) {
        return null;
    }
    return (react_1.default.createElement(ai_native_1.AIAction, { operationList: operationList, moreOperation: moreOperation, onClickItem: handleClickActions, onClose: handleClose }));
};
const debounceMessage = (0, debounce_1.default)(() => {
    ide_components_1.message.info(common_1.AiResponseTips.ERROR_RESPONSE);
}, 1000);
const AiInlineChatController = (props) => {
    const { onClickActions, onClose } = props;
    const aiInlineChatService = (0, ide_core_browser_1.useInjectable)(ide_core_browser_1.IAiInlineChatService);
    const [status, setStatus] = (0, react_1.useState)(0 /* EInlineChatStatus.READY */);
    (0, react_1.useEffect)(() => {
        const dis = aiInlineChatService.onChatStatus((status) => {
            setStatus(status);
        });
        return () => {
            dis.dispose();
        };
    }, []);
    (0, react_1.useEffect)(() => {
        if (status === 3 /* EInlineChatStatus.ERROR */) {
            debounceMessage();
            if (onClose) {
                onClose();
            }
        }
    }, [status, onClose]);
    const isLoading = (0, react_1.useMemo)(() => status === 1 /* EInlineChatStatus.THINKING */, [status]);
    const isDone = (0, react_1.useMemo)(() => status === 2 /* EInlineChatStatus.DONE */, [status]);
    const isError = (0, react_1.useMemo)(() => status === 3 /* EInlineChatStatus.ERROR */, [status]);
    const iconResultItems = (0, react_1.useMemo)(() => [
        {
            icon: 'check',
            text: '采纳',
            onClick: () => {
                aiInlineChatService._onAccept.fire();
            },
        },
        {
            icon: 'diuqi',
            text: '丢弃',
            onClick: () => {
                aiInlineChatService._onDiscard.fire();
            },
        },
        {
            icon: 'zhongxin',
            text: '重新生成',
            onClick: () => {
                aiInlineChatService._onRegenerate.fire();
            },
        },
    ], []);
    const handleClickActions = (0, react_1.useCallback)((id) => {
        if (onClickActions) {
            onClickActions.fire(id);
        }
    }, [onClickActions]);
    const translateY = (0, react_1.useMemo)(() => {
        if (isDone) {
            return {
                transform: 'translateY(-15px)',
            };
        }
        return undefined;
    }, [isDone]);
    const renderContent = (0, react_1.useCallback)(() => {
        if (isError) {
            return null;
        }
        if (isDone) {
            return react_1.default.createElement(ai_native_1.AiInlineResult, { iconItems: iconResultItems });
        }
        if (isLoading) {
            return (react_1.default.createElement("div", { className: styles.ai_inline_loading_panel },
                react_1.default.createElement(ai_native_1.EnhancePopover, { id: 'inline_chat_loading', title: '按 ESC 取消' },
                    react_1.default.createElement(Loading_1.Loading, { className: styles.ai_inline_chat_loading }))));
        }
        return react_1.default.createElement(AiInlineOperation, { hanldeActions: handleClickActions, onClose: onClose });
    }, [status]);
    return react_1.default.createElement("div", { style: translateY }, renderContent());
};
exports.AiInlineChatController = AiInlineChatController;
//# sourceMappingURL=inline-chat-controller.js.map