"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AiChatTabRenderer = exports.AiBottomTabRenderer = exports.AiRightTabRenderer = exports.AiLeftTabRenderer = void 0;
const tslib_1 = require("tslib");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const react_1 = tslib_1.__importStar(require("react"));
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const ai_native_1 = require("@opensumi/ide-core-browser/lib/components/ai-native");
const view_id_1 = require("@opensumi/ide-core-browser/lib/layout/view-id");
const ide_main_layout_1 = require("@opensumi/ide-main-layout");
const bar_view_1 = require("@opensumi/ide-main-layout/lib/browser/tabbar/bar.view");
const panel_view_1 = require("@opensumi/ide-main-layout/lib/browser/tabbar/panel.view");
const renderer_view_1 = require("@opensumi/ide-main-layout/lib/browser/tabbar/renderer.view");
const tabbar_service_1 = require("@opensumi/ide-main-layout/lib/browser/tabbar/tabbar.service");
const common_1 = require("../../../common");
const styles = tslib_1.__importStar(require("./layout.module.less"));
// 将注册在 right bar 的组件渲染到 left bar
const AiLeftTabbarRenderer = () => {
    const tabbarService = (0, ide_core_browser_1.useInjectable)(tabbar_service_1.TabbarServiceFactory)(ide_core_browser_1.SlotLocation.right);
    const layoutService = (0, ide_core_browser_1.useInjectable)(ide_main_layout_1.IMainLayoutService);
    const extraMenus = react_1.default.useMemo(() => layoutService.getExtraMenu(), [layoutService]);
    const [navMenu] = (0, ide_core_browser_1.useContextMenus)(extraMenus);
    const renderOtherVisibleContainers = (0, react_1.useCallback)(({ props, renderContainers }) => {
        const { currentContainerId, handleTabClick } = tabbarService;
        const visibleContainers = tabbarService.visibleContainers.filter((container) => { var _a; return !((_a = container.options) === null || _a === void 0 ? void 0 : _a.hideTab); });
        return (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(ai_native_1.HorizontalVertical, { margin: '8px auto 0px', width: '60%' }),
            visibleContainers.map((component) => renderContainers(component, handleTabClick, currentContainerId))));
    }, [tabbarService]);
    return (react_1.default.createElement(bar_view_1.LeftTabbarRenderer, { renderOtherVisibleContainers: renderOtherVisibleContainers, isRenderExtraTopMenus: false, renderExtraMenus: navMenu.length === 0 ? null : (react_1.default.createElement(ai_native_1.EnhanceIconWithCtxMenu, { wrapperClassName: styles.extra_bottom_icon, iconClass: navMenu[0].icon, menuNodes: navMenu[0].children, skew: { x: -8, y: -4 } })) }));
};
const AiLeftTabRenderer = ({ className, components, }) => (react_1.default.createElement(renderer_view_1.LeftTabRenderer, { className: (0, classnames_1.default)(className, styles.ai_left_slot), components: components, tabbarView: AiLeftTabbarRenderer }));
exports.AiLeftTabRenderer = AiLeftTabRenderer;
// right 面板只保留 panel
const AiRightTabRenderer = ({ className, components, }) => {
    const tabbarService = (0, ide_core_browser_1.useInjectable)(tabbar_service_1.TabbarServiceFactory)(ide_core_browser_1.SlotLocation.right);
    const handleClose = (0, react_1.useCallback)(() => {
        tabbarService.currentContainerId = '';
    }, []);
    const ContainerViewFn = (0, react_1.useCallback)((props) => {
        const { component } = props;
        const { options } = component;
        return (react_1.default.createElement(panel_view_1.ContainerView, Object.assign({}, props, { renderContainerWrap: ({ children }) => (react_1.default.createElement("div", { className: styles.right_slot_container_wrap },
                react_1.default.createElement("div", { className: styles.header },
                    react_1.default.createElement("span", { className: styles.title }, options && options.title),
                    react_1.default.createElement("div", { className: styles.side },
                        react_1.default.createElement(ai_native_1.EnhancePopover, { id: 'ai_right_panel_header_close', title: '\u5173\u95ED' },
                            react_1.default.createElement(ai_native_1.EnhanceIcon, { icon: 'close', onClick: handleClose })))),
                react_1.default.createElement("div", { className: styles.container }, children))) })));
    }, []);
    return (react_1.default.createElement(renderer_view_1.TabRendererBase, { side: ide_core_browser_1.SlotLocation.right, direction: "right-to-left" /* EDirection.RightToLeft */, id: view_id_1.VIEW_CONTAINERS.RIGHT_TABBAR_PANEL, className: (0, classnames_1.default)(className, styles.ai_right_slot), components: components, TabbarView: () => null, TabpanelView: () => react_1.default.createElement(panel_view_1.BaseTabPanelView, { PanelView: ContainerViewFn }) }));
};
exports.AiRightTabRenderer = AiRightTabRenderer;
// 编辑器 bottom 面板
const AiBottomTabRenderer = ({ className, components, }) => react_1.default.createElement(renderer_view_1.BottomTabRenderer, { className: (0, classnames_1.default)(className, styles.ai_bottom_slot), components: components });
exports.AiBottomTabRenderer = AiBottomTabRenderer;
// ai_chat 面板
const AiChatTabRenderer = ({ className, components, }) => (react_1.default.createElement(renderer_view_1.TabRendererBase, { side: common_1.Ai_CHAT_CONTAINER_VIEW_ID, direction: 'right-to-left', id: styles.ai_chat_panel, className: (0, classnames_1.default)(className, `${common_1.Ai_CHAT_CONTAINER_VIEW_ID}-slot`), components: components, TabbarView: () => null, TabpanelView: () => react_1.default.createElement(panel_view_1.BaseTabPanelView, { PanelView: panel_view_1.ContainerView, currentContainerId: common_1.Ai_CHAT_CONTAINER_VIEW_ID }) }));
exports.AiChatTabRenderer = AiChatTabRenderer;
//# sourceMappingURL=tabbar.view.js.map