"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AiRunService = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const reporter_1 = require("@opensumi/ide-core-common/lib/ai-native/reporter");
const types_1 = require("../types");
const run_feature_registry_1 = require("./run.feature.registry");
let AiRunService = class AiRunService {
    async run() {
        const runs = this.aiRunFeatureRegistry.getRuns();
        let success = true;
        const startTime = +new Date();
        const relationId = this.aiRepoter.start(reporter_1.AISerivceType.Run, { message: 'Start run' });
        try {
            for (const run of runs) {
                await run();
            }
        }
        catch (_a) {
            success = false;
        }
        this.aiRepoter.end(relationId, {
            replytime: +new Date() - startTime,
            success,
            message: 'Finished run',
            runSuccess: success,
        });
    }
    answerComponentRender() {
        return this.aiRunFeatureRegistry.getAnswerComponent();
    }
    async requestBackService(input, cancelToken) {
        const request = this.aiRunFeatureRegistry.getRequest();
        return request(input, { type: 'run' }, cancelToken);
    }
    async requestStreamBackService(input, cancelToken) {
        const request = this.aiRunFeatureRegistry.getStreamRequest();
        return request(input, { type: 'run' }, cancelToken);
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(types_1.IAiRunFeatureRegistry),
    tslib_1.__metadata("design:type", run_feature_registry_1.AiRunFeatureRegistry)
], AiRunService.prototype, "aiRunFeatureRegistry", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(reporter_1.IAIReporter),
    tslib_1.__metadata("design:type", Object)
], AiRunService.prototype, "aiRepoter", void 0);
AiRunService = tslib_1.__decorate([
    (0, di_1.Injectable)()
], AiRunService);
exports.AiRunService = AiRunService;
//# sourceMappingURL=run.service.js.map